# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bitcoin/eth/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bitcoin/eth/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bitcoin\\Eth\\": "packages/bitcoin/eth/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bitcoin\Eth\Providers\EthServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Eth'  => Bitcoin\Eth\Facades\Eth::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bitcoin\\EthTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bitcoin\Eth\Providers\EthServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bitcoin\Eth\Providers\EthServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bitcoin\Eth\Providers\EthServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/eth/{modulename}

**User**

    http://path-to-route-folder/user/eth/{modulename}

**Public**

    http://path-to-route-folder/eths


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/eth/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/eth/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/eth/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/eth/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/eth/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/eth/{modulename}/{slug}
    METHOD: GET